@@ -267,4 +267,8 @@
 #define DEFAULT_THIN_POOL_AUTOEXTEND_THRESHOLD 100
 #define DEFAULT_THIN_POOL_AUTOEXTEND_PERCENT 20
 
+#define DEFAULT_SCAN_LVS 0
+
+#define DEFAULT_IO_MEMORY_SIZE_KB 8192
+
 #endif				/* _LVM_DEFAULTS_H */
