@@ -1,4 +1,5 @@
-#!/bin/sh
+#!/usr/bin/env bash
+
 # Copyright (C) 2016 Red Hat, Inc. All rights reserved.
 #
 # This copyrighted material is made available to anyone wishing to use,
@@ -11,7 +12,7 @@
 
 # Test autoextension of thin data volume
 
-SKIP_WITH_LVMLOCKD=1
+
 SKIP_WITH_LVMPOLLD=1
 
 export LVM_TEST_THIN_REPAIR_CMD=${LVM_TEST_THIN_REPAIR_CMD-/bin/false}
@@ -35,8 +36,9 @@ aux lvmconf "activation/thin_pool_autoextend_percent = 10" \
 	    "activation/thin_pool_autoextend_threshold = 75"
 
 aux prepare_pvs 3 256
+get_devs
 
-vgcreate -s 256K $vg $(cat DEVICES)
+vgcreate $SHARED -s 256K "$vg" "${DEVICES[@]}"
 
 lvcreate -L1M -c 64k -T $vg/pool
 lvcreate -V1M $vg/pool -n $lv1
